summaryrefslogtreecommitdiffstats
path: root/system/apache-cassandra/doinst.sh
diff options
context:
space:
mode:
Diffstat (limited to 'system/apache-cassandra/doinst.sh')
-rw-r--r--system/apache-cassandra/doinst.sh20
1 files changed, 19 insertions, 1 deletions
diff --git a/system/apache-cassandra/doinst.sh b/system/apache-cassandra/doinst.sh
index 95008b7254..c7632ed9b2 100644
--- a/system/apache-cassandra/doinst.sh
+++ b/system/apache-cassandra/doinst.sh
@@ -11,7 +11,7 @@ config() {
# Otherwise, we leave the .new copy for the admin to consider...
}
# Keep same perms on rc.tomcat.new:
if [ -e etc/rc.d/rc.cassandra ]; then
cp -a etc/rc.d/rc.cassandra etc/rc.d/rc.cassandra.new.incoming
cat etc/rc.d/rc.cassandra.new > etc/rc.d/rc.cassandra.new.incoming
@@ -19,3 +19,21 @@ if [ -e etc/rc.d/rc.cassandra ]; then
fi
config etc/rc.d/rc.cassandra.new
+
+# Keep same perms on storage-conf.xml.new:
+if [ -e etc/apache-cassandra/storage-conf.xml ]; then
+ cp -a etc/apache-cassandra/storage-conf.xml etc/apache-cassandra/storage-conf.xml.new.incoming
+ cat etc/apache-cassandra/storage-conf.xml.new > etc/apache-cassandra/storage-conf.xml.new.incoming
+ mv etc/apache-cassandra/storage-conf.xml.new.incoming etc/apache-cassandra/storage-conf.xml.new
+fi
+
+config etc/apache-cassandra/storage-conf.xml.new
+
+# Keep same perms on cassandra.in.sh.new:
+if [ -e etc/apache-cassandra/cassandra.in.sh ]; then
+ cp -a etc/apache-cassandra/cassandra.in.sh etc/apache-cassandra/cassandra.in.sh.new.incoming
+ cat etc/apache-cassandra/cassandra.in.sh.new > etc/apache-cassandra/cassandra.in.sh.new.incoming
+ mv etc/apache-cassandra/cassandra.in.sh.new.incoming etc/apache-cassandra/cassandra.in.sh.new
+fi
+
+config etc/apache-cassandra/cassandra.in.sh.new \ No newline at end of file
@@ -11,7 +11,7 @@ config() {
# Otherwise, we leave the .new copy for the admin to consider...
}
-# Keep same perms on rc.tomcat.new:
+# Keep same perms on rc.cassandra.new:
if [ -e etc/rc.d/rc.cassandra ]; then
cp -a etc/rc.d/rc.cassandra etc/rc.d/rc.cassandra.new.incoming